pub struct FunctionSignatureBuilder(/* private fields */);Expand description
Represents a function signature builder.
Implementations
Sourceimpl FunctionSignatureBuilder
impl FunctionSignatureBuilder
Sourcepub fn new() -> FunctionSignatureBuilder
pub fn new() -> FunctionSignatureBuilder
Constructs a new function signature builder.
Sourcepub fn min_version(self, version: SupportedVersion) -> FunctionSignatureBuilder
pub fn min_version(self, version: SupportedVersion) -> FunctionSignatureBuilder
Sets the minimum required version for the function signature.
Sourcepub fn type_parameter(
self,
name: &'static str,
constraint: impl Constraint + 'static,
) -> FunctionSignatureBuilder
pub fn type_parameter( self, name: &'static str, constraint: impl Constraint + 'static, ) -> FunctionSignatureBuilder
Adds a constrained type parameter to the function signature.
Sourcepub fn any_type_parameter(self, name: &'static str) -> FunctionSignatureBuilder
pub fn any_type_parameter(self, name: &'static str) -> FunctionSignatureBuilder
Adds an unconstrained type parameter to the function signature.
Sourcepub fn parameter(
self,
name: &'static str,
ty: impl Into<FunctionalType>,
description: &'static str,
) -> FunctionSignatureBuilder
pub fn parameter( self, name: &'static str, ty: impl Into<FunctionalType>, description: &'static str, ) -> FunctionSignatureBuilder
Adds a parameter to the function signature.
Sourcepub fn ret(self, ret: impl Into<FunctionalType>) -> FunctionSignatureBuilder
pub fn ret(self, ret: impl Into<FunctionalType>) -> FunctionSignatureBuilder
Sets the return value in the function signature.
If this is not called, the function signature will return a Union
type.
Sourcepub fn required(self, required: usize) -> FunctionSignatureBuilder
pub fn required(self, required: usize) -> FunctionSignatureBuilder
Sets the number of required parameters in the function signature.
Sourcepub fn definition(self, definition: &'static str) -> FunctionSignatureBuilder
pub fn definition(self, definition: &'static str) -> FunctionSignatureBuilder
Sets the definition of the function.
Sourcepub fn build(self) -> FunctionSignature
pub fn build(self) -> FunctionSignature
Consumes the builder and produces the function signature.
Panics
This method panics if the function signature is invalid.